'use strict';

var test = require('ava');
var car = require('@ipld/car');
var blob = require('@web-std/blob');
var _helpers = require('./_helpers.js');
var splitter = require('../lib/treewalk/splitter.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var test__default = /*#__PURE__*/_interopDefaultLegacy(test);

test__default['default']('split in ~two', async t => {
  const targetSize = 500;
  const bytes = await _helpers.collectBytes(await _helpers.randomCar(1000));
  const blocks = await _helpers.collect((await car.CarReader.fromBytes(bytes)).blocks());
  const splitter$1 = new splitter.TreewalkCarSplitter(await car.CarReader.fromBytes(bytes), targetSize);
  const cars = [];
  for await (const car of splitter$1.cars()) {
    cars.push(car);
  }
  t.true(cars.length >= 2, `${ cars.length } >= 2`);
  const chunkedBlocks = new Map();
  for (const c of cars) {
    const reader = await car.CarReader.fromIterable(c);
    for await (const b of reader.blocks()) {
      chunkedBlocks.set(b.cid.toString(), b);
    }
  }
  t.is(blocks.length, chunkedBlocks.size);
});
test__default['default']('target size bigger than file size', async t => {
  const bytes = await _helpers.collectBytes(await _helpers.randomCar(1000));
  const splitter$1 = new splitter.TreewalkCarSplitter(await car.CarReader.fromBytes(bytes), Infinity);
  const cars = [];
  for await (const car of splitter$1.cars()) {
    cars.push(car);
  }
  t.is(cars.length, 1);
  t.true(_helpers.bytesEqual(bytes, await _helpers.collectBytes(cars[0])));
});
test__default['default']('same root in every CAR', async t => {
  const targetSize = 100;
  const bytes = await _helpers.collectBytes(await _helpers.randomCar(1000));
  const reader = await car.CarReader.fromBytes(bytes);
  const [rootCid] = await reader.getRoots();
  const splitter$1 = new splitter.TreewalkCarSplitter(reader, targetSize);
  for await (const car$1 of splitter$1.cars()) {
    const reader = await car.CarReader.fromIterable(car$1);
    const roots = await reader.getRoots();
    t.is(roots.length, 1);
    t.true(rootCid.equals(roots[0]));
  }
});
test__default['default']('bad target size', t => {
  t.throws(() => new splitter.TreewalkCarSplitter(null, -1));
});
test__default['default']('fromBlob', async t => {
  const targetSize = 500;
  const bytes = await _helpers.collectBytes(await _helpers.randomCar(1000));
  const blocks = await _helpers.collect((await car.CarReader.fromBytes(bytes)).blocks());
  const splitter$1 = await splitter.TreewalkCarSplitter.fromBlob(new blob.Blob([bytes]), targetSize);
  const cars = [];
  for await (const car of splitter$1.cars()) {
    cars.push(car);
  }
  t.true(cars.length >= 2);
  const chunkedBlocks = new Map();
  for (const c of cars) {
    const reader = await car.CarReader.fromIterable(c);
    for await (const b of reader.blocks()) {
      chunkedBlocks.set(b.cid.toString(), b);
    }
  }
  t.is(blocks.length, chunkedBlocks.size);
});
test__default['default']('fromIterable', async t => {
  const targetSize = 500;
  const bytes = await _helpers.collectBytes(await _helpers.randomCar(1000));
  const blocks = await _helpers.collect((await car.CarReader.fromBytes(bytes)).blocks());
  const splitter$1 = await splitter.TreewalkCarSplitter.fromIterable(_helpers.toAsyncIterable([bytes]), targetSize);
  const cars = [];
  for await (const car of splitter$1.cars()) {
    cars.push(car);
  }
  t.true(cars.length >= 2);
  const chunkedBlocks = new Map();
  for (const c of cars) {
    const reader = await car.CarReader.fromIterable(c);
    for await (const b of reader.blocks()) {
      chunkedBlocks.set(b.cid.toString(), b);
    }
  }
  t.is(blocks.length, chunkedBlocks.size);
});
